/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.config;

/**
 * This class is just a container of logger configuration information.
 *
 * @version $Id: LoggerConfiguration.java,v 1.2 2006/08/07 21:09:27 nichele Exp $
 */
public class LoggerConfiguration
implements java.io.Serializable {
    
    // --------------------------------------------------------------- Constants 
    
    public static final String LEVEL_OFF    = "NONE"  ;
    public static final String LEVEL_SEVERE = "ERROR" ;
    public static final String LEVEL_INFO   = "INFO"  ;
    public static final String LEVEL_ALL    = "ALL"   ;
    
    // ------------------------------------------------------------ Private data
    
    /**
     * The logger name
     */
    private String name;
    
    /**
     * The logging level
     */
    private String level;
    
    /**
     * shall the output be written to the console too?
     */
    private boolean consoleOutput;
    
    /**
     * shall the output be written to a file too?
     */
    private boolean fileOutput;
    
    /**
     * the filename pattern; it follows the FileHandler's pattern conventions.
     */
    private String pattern;
    
    /**
     * specifies an approximate maximum amount to write (in bytes) to any one 
     * file. If this is zero, then there is no limit.
     */
    private int limit;
    
    /**
     * specifies how many output files to cycle through (defaults to 1).
     */
    private int count;
    
    /**
     * specifies whether the FileHandler should append onto any existing files 
     * (defaults to false).
     */
    private boolean append;
    
    /**
     * Does this logger inheriths from its parent logger?
     */
    private boolean inherit;
    
    // ------------------------------------------------------------ Constructors
    
    /** Creates a new instance of LoggingConfiguration */
    public LoggerConfiguration() {
    }
    
    // ---------------------------------------------------------- Public methods
    
    /**
     * Getter for property level.
     * @return Value of property level.
     */
    public String getLevel() {
        return level;
    }
    
    /**
     * Setter for property level.
     * @param level New value of property level.
     */
    public void setLevel(String level) {
        this.level = level;
    }
    
    /**
     * Getter for property consoleOutput.
     * @return Value of property consoleOutput.
     */
    public boolean isConsoleOutput() {
        return consoleOutput;
    }
    
    /**
     * Setter for property consoleOutput.
     * @param consoleOutput New value of property consoleOutput.
     */
    public void setConsoleOutput(boolean consoleOutput) {
        this.consoleOutput = consoleOutput;
    }
    
    /**
     * Getter for property fileOutput.
     * @return Value of property fileOutput.
     */
    public boolean isFileOutput() {
        return fileOutput;
    }
    
    /**
     * Setter for property fileOutput.
     * @param fileOutput New value of property fileOutput.
     */
    public void setFileOutput(boolean fileOutput) {
        this.fileOutput = fileOutput;
    }
    
    /**
     * Getter for property pattern.
     * @return Value of property pattern.
     */
    public java.lang.String getPattern() {
        return pattern;
    }
    
    /**
     * Getter for property limit.
     * @return Value of property limit.
     */
    public int getLimit() {
        return limit;
    }
    
    /**
     * Setter for property limit.
     * @param limit New value of property limit.
     */
    public void setLimit(int limit) {
        this.limit = limit;
    }
    
    /**
     * Setter for property pattern.
     * @param pattern New value of property pattern.
     */
    public void setPattern(java.lang.String pattern) {
        this.pattern = pattern;
    }
    
    /**
     * Getter for property count.
     * @return Value of property count.
     */
    public int getCount() {
        return count;
    }
    
    /**
     * Setter for property count.
     * @param count New value of property count.
     */
    public void setCount(int count) {
        this.count = count;
    }
    
    /**
     * Getter for property append.
     * @return Value of property appen.
     */
    public boolean isAppend() {
        return append;
    }
    
    /**
     * Setter for property append.
     * @param append New value of property append.
     */
    public void setAppend(boolean append) {
        this.append = append;
    }
    
    /**
     * Getter for property name.
     * @return Value of property name.
     */
    public String getName() {
        return name;
    }    
    
    /**
     * Setter for property name.
     * @param name New value of property name.
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * Getter for property inherit.
     * @return Value of property inherit.
     */
    public boolean isInherit() {
        return inherit;
    }
    
    /**
     * Setter for property inherit.
     * @param inherit New value of property inherit.
     */
    public void setInherit(boolean inherit) {
        this.inherit = inherit;
    }
    
}
