/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

import java.util.*;

/**
 * This class corresponds to the &lt;CTCap&gt; tag in the SyncML devinf DTD v1.2
 *
 * @version $Id: CTCap.java,v 1.4 2006/09/07 11:32:33 nichele Exp $
 */
public class CTCap implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private ContentTypeInfo ctInfo    ;
    private Boolean         fieldLevel;
    private ArrayList properties = new ArrayList();

    // ------------------------------------------------------------ Constructors
    /**
     * In order to expose the server configuration like WS this constructor
     * must be public
     */
    public CTCap() {}

    /**
     * Creates a new CTCap object with the given type, version, field-level and
     * an array of properties
     *
     * @param ctInfo The type and version of a supported content type - NOT NULL
     * @param fieldLevel The capability to apply field-level replaces for the
     *                   corresponding CTType
     * @param properties The array of supported properties of a given content
     *                   type - NOT NULL
     *
     */
    public CTCap(final ContentTypeInfo ctInfo,
                 final boolean fieldLevel    ,
                 final Property[] properties ) {
        setCTInfo(ctInfo);
        this.fieldLevel = (fieldLevel) ? new Boolean(fieldLevel) : null;
        setProperties(properties);
    }
    // ---------------------------------------------------------- Public methods

    /**
     * Get a ContentTypeInfo object
     *
     * @return a ContentTypeInfo object
     */
    public ContentTypeInfo getCTInfo() {
        return this.ctInfo;
    }

    /**
     * Sets a ContentTypeInfo object
     *
     * @param ctInfo The ContentTypeInfo object
     */
    public void setCTInfo(ContentTypeInfo ctInfo) {
        if (ctInfo == null) {
            throw new IllegalArgumentException("ctInfo cannot be null");
        }
        this.ctInfo = ctInfo;
    }

    /**
     * Sets the field-level
     *
     * @param fieldLevel the Boolean value of FieldLevel property
     */
    public void setFieldLevel(Boolean fieldLevel) {
        this.fieldLevel = (fieldLevel.booleanValue()) ? fieldLevel : null;
    }

    /**
     * Gets the value of FieldLevel property
     *
     * @return true if the sender is able to apply field-level replaces for the
     *         corresponding CTType property, otherwise false
     */
    public boolean isFieldLevel() {
        return (fieldLevel != null);
    }

    /**
     * Gets the value of FieldLevel property
     *
     * @return true if the sender is able to apply field-level replaces for the
     *         corresponding CTType property, otherwise false
     */
    public Boolean getFieldLevel() {
        if (fieldLevel == null || !fieldLevel.booleanValue()) {
            return null;
        }
        return fieldLevel;
    }

    /**
     * Get an array of supported properties of a given content type
     *
     * @return an array of supported properties
     */
    public ArrayList getProperties() {
        return this.properties;
    }

    /**
     * Sets an array of supported properties of a given content type
     *
     * @param properties an array of supported properties
     */
    public void setProperties(Property[] properties) {

        if (properties == null || properties.length == 0) {
            throw new IllegalArgumentException("properties cannot be null");
        }
        this.properties.clear();
        this.properties.addAll(Arrays.asList(properties));
    }

    /**
     * Sets an array of supported properties of a given content type
     *
     * @param properties an array of supported properties
     */
    public void setProperties(ArrayList properties) {

        if (properties == null || properties.size() == 0) {
            throw new IllegalArgumentException("properties cannot be null");
        }
        this.properties.clear();
        this.properties.addAll(properties);
    }
}
