/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

/**
 * This class represents the &lt;Filter&gt; tag ias defined by the SyncML
 * representation specifications
 *
 * @version $Id: Filter.java,v 1.3 2006/09/07 11:32:33 nichele Exp $
 */
public class Filter implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private Meta   meta      ;
    private Item   field     ;
    private Item   record    ;
    private String filterType;

    // ------------------------------------------------------------ Constructors

    protected Filter() {}

    /**
     * Creates a new Filter object.
     *
     * @param meta       the meta information - NOT NULL
     * @param field      the field item data
     * @param record     the record item data
     * @param filterType the type of filtering
     */
    public Filter(final Meta   meta      ,
                  final Item   field     ,
                  final Item   record    ,
                  final String filterType) {

        this.meta       = meta      ;
        this.field      = field     ;
        this.record     = record    ;
        this.filterType = filterType;
    }

    // ---------------------------------------------------------- Public methods
    /**
     * Returns the meta information
     *
     * @return the meta information
     */
    public Meta getMeta() {
        return meta;
    }

    /**
     * Sets the meta information
     *
     * @param meta the meta information
     */
    public void setMeta(Meta meta) {
        if (meta == null) {
            throw new IllegalArgumentException("meta cannot be null");
        }
        this.meta = meta;
    }

    /**
     * Returns the item field data
     *
     * @return the item field data
     */
    public Item getField() {
        return field;
    }

    /**
     * Sets a field level filter to be performed on the parent element of
     * the filter
     *
     * @param field the item field data
     */
    public void setField(Item field) {
        this.field = field;
    }

    /**
     * Returns the item record data
     *
     * @return the item record data
     */
    public Item getRecord() {
        return record;
    }

    /**
     * Sets a record level filter to be performed on the parent element of
     * the filter
     *
     * @param record the item record data
     */
    public void setRecord(Item record) {
        this.record = record;
    }

    /**
     * Returns the type of filtering
     *
     * @return the type of filtering
     */
    public String getFilterType() {
        return filterType;
    }

    /**
     * Sets the type of filtering
     *
     * @param filterType the type of filtering
     */
    public void setFilterType(String filterType) {
        this.filterType = filterType;
    }

}
