/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * This class represents the filtering capabilities
 *
 * @version $Id: FilterCap.java,v 1.3 2006/09/07 11:32:33 nichele Exp $
 */
public class FilterCap implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private ContentTypeInfo ctInfo        ;
    private ArrayList       filterKeywords = new ArrayList();
    private ArrayList       propNames      = new ArrayList();

    // ------------------------------------------------------------ Constructors
    /**
     * In order to expose the server configuration like WS this constructor
     * must be public
     */
    public FilterCap() {}

    /**
     * Creates a new FilterCap object with the given input information
     *
     * @param ctInfo The type and version of a supported content type - NOT NULL
     * @param filterKeyword The record level filter keyword
     * @param propName      The name of a supported property
     */
    public FilterCap(final ContentTypeInfo ctInfo        ,
                     final String[]        filterKeywords,
                     final String[]        propNames     ) {
        setCTInfo(ctInfo);
        setFilterKeywords(filterKeywords);
        setPropNames(propNames);
    }

    // ---------------------------------------------------------- Public methods
    /**
     * Get a ContentTypeInfo object
     *
     * @return a ContentTypeInfo object
     */
    public ContentTypeInfo getCTInfo() {
        return this.ctInfo;
    }

    /**
     * Sets a ContentTypeInfo object
     *
     * @param ctInfo The ContentTypeInfo object
     */
    public void setCTInfo(ContentTypeInfo ctInfo) {
        if (ctInfo == null) {
            throw new IllegalArgumentException("ctInfo cannot be null");
        }
        this.ctInfo = ctInfo;
    }

    /**
     * Get the record level filter keyword
     *
     * @return the record level filter keyword
     */
    public ArrayList getFilterKeywords() {
        return this.filterKeywords;
    }

    /**
     * Sets the record level filter keyword
     *
     * @param filterKeywords The record level filter keyword
     */
    public void setFilterKeywords(String[] filterKeywords) {
        if (filterKeywords != null) {
            this.filterKeywords.clear();
            this.filterKeywords.addAll(Arrays.asList(filterKeywords));
        } else {
            this.filterKeywords = null;
        }
    }

    /**
     * Sets the record level filter keyword
     *
     * @param filterKeywords The record level filter keyword
     */
    public void setFilterKeywords(ArrayList filterKeywords) {
        if (filterKeywords != null) {
            this.filterKeywords.clear();
            this.filterKeywords.addAll(filterKeywords);
        } else {
            this.filterKeywords = null;
        }
    }

    /**
     * Get the name of a supported property
     *
     * @return the name of a supported property
     */
    public ArrayList getPropNames() {
        return this.propNames;
    }

    /**
     * Sets the name of a supported property
     *
     * @param propNames The name of a supported property
     */
    public void setPropNames(String[] propNames) {
        if (propNames != null) {
            this.propNames.clear();
            this.propNames.addAll(Arrays.asList(propNames));
        } else {
            this.propNames = null;
        }
    }

    /**
     * Sets the name of a supported property
     *
     * @param propNames The name of a supported property
     */
    public void setPropNames(ArrayList propNames) {
        if (propNames != null) {
            this.propNames.clear();
            this.propNames.addAll(propNames);
        } else {
            this.propNames = null;
        }
    }
}
