/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

/**
 * This class represents the &lt;VerProto&gt; tag as defined by the SyncML r
 * epresentation specifications.
 *
 * @version $Id: VerProto.java,v 1.4 2006/09/07 11:32:33 nichele Exp $
 */
public class VerProto
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private String version;

    // ------------------------------------------------------------ Constructors

    /**
     * For serialization purposes
     */
    protected VerProto() {}

    /**
     * Creates a new VerProto object from its version.
     *
     * @param version the protocol version - NOT NULL
     *
     */
    public VerProto(final String version) {
        setVersion(version);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the protocol version.
     *
     * @return the protocol version - NOT NULL
     *
     */
    public String getVersion() {
        return version;
    }

    /**
     * Sets the protol version.
     *
     * @param version the protocol version - NOT NULL
     *
     * @throws IllegalArgumentException if version is null
     */
    public void setVersion(String version) {
        if (version == null) {
            throw new IllegalArgumentException("version cannot be null");
        }
        this.version = version;
    }

    /**
     * Compares this VerProto with a given object. If obj is a VerProto,
     * versions are compared as stored internally. if obj is null, false is
     * returned. If obj is a String, the string representation of this VerProto
     * is used for the comparison. If obj is neither a VerProto nor a String,
     * String.valueOf(obj) is used for the comparison
     *
     * @param obj the obect to be compared
     *
     * @return true if the two object represent the same information
     */
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        String s = null;
        if (obj instanceof VerProto) {
            s = ((VerProto)obj).getVersion();
        } else if (obj instanceof String) {
            s = (String)obj;
        } else {
            s = String.valueOf(obj);
        }

        return (s.equals(version));
    }
}
