/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.engine;

import com.funambol.framework.core.Sync4jException;
import com.funambol.framework.security.Sync4jPrincipal;


/**
 * Abstract base implementation of <i>SyncEngine</i>. <br>
 * Subclasses must at least redefine the following methods:
 * <ul>
 *   <li><i>sync()</i>
 *   <li><i>getModifiedSources()</i>
 *   <li><i>addModifiedSource()</i>
 * </ul>
 *
 * @version $Id: AbstractSyncEngine.java,v 1.3 2006/08/07 21:09:29 nichele Exp $
 *
 */
public abstract class AbstractSyncEngine
implements SyncEngine, java.io.Serializable {
    /**
     * The underlying strategy.
     */
    private SyncStrategy strategy = null;

    /**
     * Get the underlying strategy
     *
     * @return the underlying strategy
     */
    public SyncStrategy getStrategy() {
        return this.strategy;
    }

    /**
     * Set the synchronization strategy to be used
     */
    public void setStrategy(SyncStrategy strategy) {
        this.strategy = strategy;
    }

    /**
     * @see com.funambol.framework.engine.SyncEngine
     */
    abstract public void sync(Sync4jPrincipal principal)
        throws Sync4jException;

    /**
     * @see com.funambol.framework.engine.SyncEngine
     */
    abstract public void endSync()
        throws Sync4jException;
}
