/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.engine;

/**
 * This class represents a unique identifier of a <i>SyncItem</i> item in a repository.
 *
 * @version $Id: SyncItemKey.java,v 1.3 2006/08/07 21:09:29 nichele Exp $
 */
public class SyncItemKey implements Comparable , java.io.Serializable {

    // -------------------------------------------------------------- Properties

    /**
     * The key value
     */
    private Object keyValue = null;
    public Object getKeyValue(){
        return keyValue;
    }

    /**
     * @param keyValue the key - NOT NULL (assert checked)
     */
    public void setKeyValue(Object keyValue){
        assert (keyValue != null);
        this.keyValue = keyValue;
    }

    // ------------------------------------------------------------ Constructors

    /**
     * @param keyValue the key - NOT NULL (assert checked)
     */
    public SyncItemKey(Object keyValue) {
        assert (keyValue != null);
        this.keyValue = keyValue;
    }

    // ---------------------------------------------------------- Public Methods

    /**
     * @return this key's value as a String object (calling toString() on the
     *         value object)
     */
    public String getKeyAsString() {
        return keyValue.toString();
    }

    /**
     * Two keys are equal if their keyValues are equal.
     * The keys are objects but they have to be considered as String object
     * to be compared.
     *
     * @param o the object this instance must be compared to.
     *
     * @return the given object is equal to this object
     */
    public boolean equals(Object o) {
        if (!(o instanceof SyncItemKey)) return false;

        return ((SyncItemKey)o).getKeyAsString().equals(getKeyAsString());
    }

    /**
     * Returns the hash code of this object
     *
     * @return the hash code of this object
     */
    public int hashCode() {
        return getKeyAsString().hashCode();
    }

    /**
     * @return a string representation for debugging purposes of this <i>SyncItemKey</i>.
     */
    public String toString() {
        StringBuffer sb = new StringBuffer();

        sb.append( " { keyValue: "  );
        sb.append( getKeyAsString() );
        sb.append( " } "            );

        return sb.toString();
    }

    /**
     * Compares two SyncItemKey based on the string representation of the key value
     * @param o Object
     * @return int
     */
    public int compareTo(Object o) {

        if (!(o instanceof SyncItemKey)) {
            throw new ClassCastException("A SyncItemKey object expected.");
        }
        SyncItemKey otherKey = (SyncItemKey)o;

        if (keyValue != null && otherKey.getKeyValue() != null) {
            return keyValue.toString().compareTo(otherKey.getKeyValue().toString());
        }
        if (keyValue == null && otherKey.getKeyValue() == null) {
            return 0;
        }

        return -1;
    }
}
