/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.engine;

import java.security.Principal;

import com.funambol.framework.engine.SyncItem;

/**
 * This interface represents a synchronization operation between two items.
 * The possible operations are:
 * <ul>
 * <li>create
 * <li>update
 * <li>delete
 * </ul>
 *
 *
 *
 * @version $Id: SyncOperation.java,v 1.2 2006/08/07 21:09:29 nichele Exp $
 */
public interface SyncOperation {

    public static final char NEW          = 'N';
    public static final char DELETE       = 'D';
    public static final char UPDATE       = 'U';
    public static final char CONFLICT     = 'O';
    public static final char ACCEPT_CHUNK = 'A';
    public static final char NOP          = '-';

    public SyncItem getSyncItemA();
    public void setSyncItemA(SyncItem syncItemA);

    public SyncItem getSyncItemB();
    public void setSyncItemB(SyncItem syncItemB);

    /**
     * Does the operation apply to the client source
     *
     * @return true if the operation applies to the client source or false otherwise.
     */
    public boolean isAOperation();
    public void setAOperation(boolean a);

    /**
     * Does the operation apply to the server source*
     *
     * @return true if the operation applies to the server source or false otherwise.
     */
    public boolean isBOperation();
    public void setBOperation(boolean b);

    public char getOperation();

    /**
     * The principal that requested this operation.
     *
     * @return the principal that requested this operation. It may be null.
     */
    public Principal getOwner();

    /**
     * Is the delete on the client item required ?
     * @return boolean
     */
    public boolean isDeleteForced();

}
