/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine;

import com.funambol.framework.engine.SyncOperation;
import com.funambol.framework.engine.source.SyncSource;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This class represents a <i>SyncOperation</i> status.
 *
 *
 *
 * @version $Id: SyncOperationStatus.java,v 1.2 2006/08/07 21:09:29 nichele Exp $
 *
 */
public class SyncOperationStatus {

    // -------------------------------------------------------------- Properties

    /**
     * The operation this object represents the execution for
     */
    private SyncOperation operation;

    /** Getter for property operation.
     * @return Value of property operation.
     *
     */
    public SyncOperation getOperation() {
        return operation;
    }

    /**
     * The source the operation was executed on
     */
    private SyncSource syncSource;

    /** Getter for property syncSource.
     * @return Value of property syncSource.
     *
     */
    public SyncSource getSyncSource() {
        return syncSource;
    }

    /**
     * The status code
     */
    private int statusCode;

    /**
     * Getter for property statusCode.
     * @return Value of property syncSource.
     *
     */
    public int getStatusCode() {
        return statusCode;
    }


    // ------------------------------------------------------------- Contructors

    /**
     * Creates a new instance of SyncOperationStatus
     *
     * @param operation the operation - NOT NULL
     * @param syncSource the source - NOT NULL
     * @param statusCode the status code
     *
     * @throws IllegalArgumentException in case operation is null
     */
    public SyncOperationStatus( SyncOperation operation  ,
                                SyncSource    syncSource ,
                                int           statusCode ) {
        if (operation == null) {
            throw new IllegalArgumentException("operation cannnot be null");
        }
        if (syncSource == null) {
            throw new IllegalArgumentException("syncSource cannnot be null");
        }

        this.operation  = operation ;
        this.syncSource = syncSource;
        this.statusCode = statusCode;
    }

    /**
     * Creates a new instance of SyncOperationStatus
     *
     * @param operation the operation - NOT NULL
     * @param syncSource the source - NOT NULL
     *
     * @throws IllegalArgumentException in case operation is null
     */
    public SyncOperationStatus( SyncOperation operation  ,
                                SyncSource    syncSource ) {
        this(operation, syncSource, -1);
    }

    // ---------------------------------------------------------- Public methods

    public String toString() {
        return new ToStringBuilder(this).
            append("operation",  operation.toString() ).
            append("syncSource", syncSource.toString()).
            append("statusCode", getStatusCode()).
            toString();
    }

}
