/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine;

import com.funambol.framework.engine.SyncOperation;
import com.funambol.framework.engine.source.SyncSource;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This class represents the status of a Sync operation on a SyncSource.
 *
 *
 * @version $Id: SyncStatus.java,v 1.2 2006/08/07 21:09:29 nichele Exp $
 *
 */
public class SyncStatus {

    // -------------------------------------------------------------- Properties

    /**
     * The status code
     */
    protected int statusCode;

    /**
     * Getter for property statusCode.
     * @return Value of property syncSource.
     *
     */
    public int getStatusCode() {
        return statusCode;
    }

    /**
     * Sets the operation status code
     *
     * @param statusCode the new statusCode
     */
    public void setStatusCode(int statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * An optional status description
     */
    private String message;

    /**
     * Getter for property message.
     * @return Value of property message.
     *
     */
    public String getMessage() {
        return message;
    }

    /**
     * Sets the operation message code
     *
     * @param message the new message
     */
    public void setMessage(String message) {
        this.message = message;
    }

    /**
     * The source the operation was executed on
     */
    protected SyncSource syncSource;

    /** Getter for property syncSource.
     * @return Value of property syncSource.
     *
     */
    public SyncSource getSyncSource() {
        return syncSource;
    }


    // ------------------------------------------------------------- Contructors

    /**
     * Just for sbclasses
     */
    protected SyncStatus() {
        syncSource = null;
        statusCode =   -1;
    }

    /**
     * Creates a new instance of SyncStatus
     *
     * @param syncSource the source - NOT NULL
     * @param statusCode the statusCode
     *
     * @throws IllegalArgumentException in case operation is null
     */
    public SyncStatus(SyncSource syncSource, int statusCode, String message) {
        if (syncSource == null) {
            throw new IllegalArgumentException("syncSource cannnot be null");
        }

        this.syncSource = syncSource;
        this.statusCode = statusCode;
        this.message    = message   ;
    }

    /**
     * Creates a new instance of SyncStatus with an unknown status code
     *
     * @param syncSource the source - NOT NULL
     *
     * @throws IllegalArgumentException in case operation is null
     */
    public SyncStatus(SyncSource syncSource) {
        this(syncSource, -1, "");
    }

    // ---------------------------------------------------------- Public methods

}
