/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.protocol.v11;

import com.funambol.framework.core.*;

import com.funambol.framework.protocol.ProtocolException;
import com.funambol.framework.protocol.v11.BasicRequirements;
import com.funambol.framework.protocol.v11.Errors;

/**
 * This class groups utility methods used for checking that an initialization
 * massage follows the requirements that the protocol mandates.
 *
 *
 *
 * @version $Id: InitializationRequirements.java,v 1.3 2006/08/07 21:09:31 nichele Exp $
 */
public class InitializationRequirements
extends BasicRequirements
implements Errors {

    // --------------------------------------------------------------- Constants

    // ---------------------------------------------------------- Public methods

    static public void checkAlertCommand(Alert alert) throws ProtocolException {
        try {
            BasicRequirements.checkAlertCommand(alert);
        } catch (ProtocolException e) {
            String[] args = new String[] { e.getMessage() };
            throw new ProtocolException(ERRMSG_INVALID_ALERT, args);
        }

        //
        // Checks the alert code
        //
        if (!AlertCode.isInitializationCode(alert.getData())) {
            String[] args = new String[] { String.valueOf(alert.getData()) };
            throw new ProtocolException(ERRMSG_INVALID_ALERT_CODE, args);
        }

        //
        // Checks source and target
        //
        Item[] items = (Item[])alert.getItems().toArray(new Item[0]);

        if ((items == null) || (items.length ==0)) {
            throw new ProtocolException(ERRMSG_MISSING_ITEM);
        }

        try {
            checkSource(items[0].getSource());
        } catch (ProtocolException e) {
            String[] args = new String[] { "source" };
            throw new ProtocolException(ERRMSG_INVALID_ALERT, args);
        }

        try {
            checkTarget(items[0].getTarget());
        } catch (ProtocolException e) {
            String[] args = new String[] { "target" };
            throw new ProtocolException(ERRMSG_INVALID_ALERT, args);
        }

        //
        // The Alert 224 (Suspend) doesn't contain the anchor, so we mustn't check it
        //
        if (alert.getData() != AlertCode.SUSPEND) {
            //
            // Checks sync anchors
            //
            Meta meta = items[0].getMeta();

            if (meta == null || meta.getAnchor() == null) {
                throw new ProtocolException(ERRMSG_MISSING_SYNC_ANCHOR);
            }
        }
    }

    /**
     * Checks if the given command contains a valid request for server capablities.
     *
     * @param cmd the command containing the request
     *
     * @throws ProtocolException
     */
    static public void checkCapabilitiesRequest(Get cmd)
    throws ProtocolException {
        //
        // Checks command id
        //
        try {
            checkCommandId(cmd.getCmdID());
        } catch (ProtocolException e) {
            String[] args = new String[] { e.getMessage() };
            throw new ProtocolException(ERRMSG_INVALID_CAPABILITIES, args);
        }

        Item[] items = (Item[])cmd.getItems().toArray(new Item[0]);

        if ((items == null) || (items.length ==0)) {
            String[] args = new String[] {ERRMSG_MISSING_ITEM};
            throw new ProtocolException(ERRMSG_INVALID_CAPABILITIES_REQUEST, args);
        }

        try {
            checkTarget(items[0].getTarget());
        } catch (ProtocolException e) {
            String[] args = new String[] { "missing target" };
            throw new ProtocolException(ERRMSG_INVALID_CAPABILITIES_REQUEST, args);
        }
    }
}
