/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.security;

import java.security.Principal;

import com.funambol.framework.core.Cred;

/**
 * This the interface that defines how credentials are authenticated to a device
 * and how resources are authorized for a given credential.
 *
 *.com
 * @version $Id: Officer.java,v 1.2 2006/08/07 21:13:13 nichele Exp $
 */
public interface Officer {
    
    /**
     * Authenticates a credential.
     *
     * @param credential the credential to be authenticated
     *
     * @return true if the credential is autenticated, false otherwise
     */
    public boolean authenticate(Cred credential);
    
    /**
     * Un-authenticates a credential.
     * 
     * @param credential the credential to be unauthenticated
     */
    public void unAuthenticate(Cred credential);
    
    /**
     * Authorizes a resource.
     *
     * @param credential the requesting entity
     * @param resource the name (or the identifier) of the resource to be authorized
     *
     * @return true if the credential is authorized to access the resource, false
     *         otherwise
     */
    public boolean authorize(Principal credential, String resource);

    /**
     * Is the account authenticated by this officer expired?
     *
     * @return true if the account is expired, false otherwise
     */
    public boolean isAccountExpired();
    
    /**
     * Read property client_auth
     *
     * @return the authentication's type the server requires to client
     *         to authenticate it
     */
    public String getClientAuth();
    
    /**
     * Read property server_auth
     *
     * @return the authentication's type the client requires to server to 
     *         authenticate it
     */
    public String getServerAuth();
}

