/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.security;

import java.security.Principal;

import com.funambol.framework.security.Officer;
import com.funambol.framework.core.Cred;

/**
 * This is a simple implementation of the <i>Officier</i> interface. It always
 * authenticates and authorizes users and resource accesses.
 *
 *.com
 * @version $Id: SimpleOfficer.java,v 1.2 2006/08/07 21:13:13 nichele Exp $
 */
public class SimpleOfficer implements Officer {
    
    /**
     * Authenticates a credential.
     *
     * @param credential the credential to be authenticated
     *
     * @return true if the credential is autenticated, false otherwise
     */
    public boolean authenticate(Cred credential) {
        return true;
    }
    
    /**
     * Authorizes a resource.
     *
     * @param principal the requesting entity
     * @param resource the name (or the identifier) of the resource to be authorized
     *
     * @return true if the credential is authorized to access the resource, false
     *         otherwise
     */
    public boolean authorize(Principal principal, String resource) {
        return true;
    }
    
    /** Un-authenticates a credential.
     *
     * @param credential the credential to be unauthenticated
     */
    public void unAuthenticate(Cred credential) {
    }    
    
    /**
     * @see com.funambol.framework.security.Officer
     */
    public boolean isAccountExpired() {
        return false;
    }
    
    // ------------------------------------------------------------ Private data
    
    /**
     * Which type of authetication does impose the server?
     */
    private String clientAuth = Cred.AUTH_TYPE_BASIC;
    public String getClientAuth() {
        return this.clientAuth;
    }
    
    public void setClientAuth(String clientAuth) {
        this.clientAuth = clientAuth;
    }
    
    /**
     * Which type of authetication use the server to send his credential?
     */
    private String serverAuth = Cred.AUTH_NONE;
    public String getServerAuth() {
        return this.serverAuth;
    }
    
    public void setServerAuth(String serverAuth) {
        this.serverAuth = serverAuth;
    }
}