/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.server;

import java.io.Serializable;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * Represents a synchronization timestamp for a particular database and principal.
 * <i>tag</i> stores the next (when used as a next timestamp) or the last (when
 * used as a last timstamp) value as it appears in <i>SyncAnchor</i>.
 *
 * @version $Id: SyncTimestamp.java,v 1.2 2006/08/07 21:13:13 nichele Exp $
 */
public class SyncTimestamp implements Serializable {

    // ------------------------------------------------------------- Public data

    public long   start     = -1  ;  // timestamp of when sync started
    public long   end       = -1  ;  // timestamp of when sync ended
    public String tagServer = null;  // the last/next tag of the server
    public String tagClient = null;  // the last/next tag of the client
    public int    syncType  = -1  ;  // the alert code of the sync
    public int    status    = -1  ;  // the status code of the sync

    // ------------------------------------------------------------ Constructors

    /** Creates a new instance of LastTimestamp */
    public SyncTimestamp() { }

    /**
     * Creates a new instance of SyncTimestamp when the only starting timestamp
     * is known. <i>end</i> is set to -1 and tag is set to the string value
     * of the start.
     *
     * @param start the starting timestamp
     */
    public SyncTimestamp(final long start) {
        this(String.valueOf(start), String.valueOf(start), start, -1, -1, -1);
    }

    /**
     * Creates a new instance of LastTimestamp.
     * It is need to cache the next anchor of the server and the next anchor
     * of the client.
     *
     * @param tagServer the last/next tag of the server
     * @param tagClient the last/next tag of the client
     * @param start the timestamp of when sync started
     * @param end the timestamp of when sync ended
     * @param syncType the alert code of the sync
     *
     */
    public SyncTimestamp(final String tagServer,
                         final String tagClient,
                         final long   start    ,
                         final long   end      ,
                         final int    syncType ,
                         final int    status) {
        this.tagServer = tagServer;
        this.tagClient = tagClient;
        this.start     = start    ;
        this.end       = end      ;
        this.syncType  = syncType ;
        this.status    = status   ;
    }

    // ---------------------------------------------------------- Public methods

    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

        sb.append("tagServer", tagServer).
           append("tagClient", tagClient).
           append("start"    , new java.sql.Timestamp(start)).
           append("end"      , new java.sql.Timestamp(end)).
           append("syncType" , syncType).
           append("status"   , status);

        return sb.toString();
    }
}
