/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.tools.beans;

/**
 * This interface models beans that supports or requires lazy initialization.
 * When a bean is created, first of all the empty constructor is created and
 * the the bean properties are set. If a bean requires that its properties have 
 * a proper value when initialization is performed it should implement 
 * <i>LazyInitBean</i>, so that the caller has an opportunity to separately 
 * initialize the bean after its creation, but before using it.<br>
 * The described mechanism is used in BeanFactory when an instance of the bean
 * is created. If the bean implements <i>LazyInitBean</i> after creating the bean
 * the method init() is called.
 * 
 * @see BeanFactory
 *
 *
 * @version $Id: LazyInitBean.java,v 1.2 2006/08/07 21:13:15 nichele Exp $
 */
public interface LazyInitBean {
    public void init() throws BeanInitializationException;
}