/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.server.syncbean;

import java.util.Map;

import javax.ejb.*;

import com.funambol.framework.server.SyncResponse;
import com.funambol.framework.server.error.ServerException;

 /**
  *
  * @version $Id: SyncRemote.java,v 1.3 2006/08/07 21:13:17 nichele Exp $
  */
public interface SyncRemote extends javax.ejb.EJBObject {

    /**
     * Processes an incoming XML message.
     *
     * @param requestURI the uri of the request
     * @param requestData the SyncML request as stream of bytes
     * @param parameters SyncML request parameters
     * @param headers SyncML request headers
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processXMLMessage(final String requestURI ,
                                          final byte[] requestData,
                                          final Map    parameters ,
                                          final Map    headers    )
    throws java.rmi.RemoteException, ServerException;

    /**
     * Processes an incoming WBXML message.
     *
     * @param requestURI the uri of the request
     * @param requestData the SyncML request as stream of bytes
     * @param parameters SyncML request parameters
     * @param headers SyncML request headers
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processWBXMLMessage(final String requestURI ,
                                            final byte[] requestData,
                                            final Map    parameters ,
                                            final Map    headers    )
    throws java.rmi.RemoteException, ServerException;

    /**
     * Used to process a status information as needed by the client object (i.e.
     * errors or success).
     *
     * @param statusCode the status code
     * @param info additional information message
     *
     * @return the response message
     *
     * @throws java.rmi.RemoteException
     *
     * @see com.funambol.framework.core.StatusCode for valid status codes.
     *
     */
    public SyncResponse processStatusCode(int statusCode, String info)
    throws java.rmi.RemoteException;
}

