/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.server.tools;

import com.funambol.framework.protocol.IdGenerator;
import com.funambol.framework.server.ID;
import com.funambol.framework.server.store.*;

import com.funambol.server.config.Configuration;

/**
 * This class works as a simple id generator that read his value from the datastore
 *
 * @version $Id: IdSpaceGenerator.java,v 1.2 2006/08/07 21:13:18 nichele Exp $
 */
public class IdSpaceGenerator
implements IdGenerator, java.io.Serializable {

    // -------------------------------------------------------------- Properties
    private ID id = null;

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new instance of IdSpaceGenerator
     *
     * @param idSpace the id space
     */
    public IdSpaceGenerator(String idSpace) {
        id = new ID(idSpace);
    }


    /**
     * Reset the generator to 0.
     */
    public void reset() {
        id.setValue(0);
        try {
            Configuration.getConfiguration().getStore().store(id);
        } catch (PersistentStoreException ex) {
            throw new IllegalStateException("Error resetting the counter '" + id.getIdSpace() + "': " + ex.getMessage());
        }
    }

    /**
     * Returns the next value of the counter
     *
     * @return the next generated value
     */
    public synchronized String next() {
        try {
            Configuration.getConfiguration().getStore().read(id);
        } catch (PersistentStoreException ex) {
            throw new IllegalStateException("Error reading the counter '" + id.getIdSpace() + "': " + ex.getMessage());
        }
        return String.valueOf(id.getValue());
    }

    /**
     * Returns the last generated id (which is the current id).
     *
     * @return the last generated id
     */
    public synchronized String current() {
        return String.valueOf(id.getValue());
    }
}
