--
-- This script contains the ddl to create the engine database.
--
-- @version $Id: create_engine.ddl,v 1.4 2006/08/08 08:28:19 nichele Exp $
--

create table fnbl_user (
  username   varchar(255) binary not null,
  password   varchar(255) binary not null,
  email      varchar(50)  binary,
  first_name varchar(255) binary,
  last_name  varchar(255) binary,
  
  constraint pk_user primary key (username)
);

create table fnbl_device (
  id                   varchar(128) binary not null,
  description          varchar(255),
  type                 varchar(255),
  client_nonce         varchar(255),
  server_nonce         varchar(255),
  server_password      varchar(255),
  timezone             varchar(32) ,
  convert_date         char(1)     ,
  charset              varchar(16) ,
  address              varchar(50) ,
  msisdn               varchar(50) ,
  notification_builder varchar(255),
  notification_sender  varchar(255),
  id_caps              integer     ,
  
  constraint pk_device primary key (id)
);

create table fnbl_principal (
  username varchar(255)  binary not null,
  device   varchar(128) binary not null,
  id       integer      not null,
  
  constraint pk_principal primary key (id),
  
  constraint fk_user foreign key (username)
  references fnbl_user (username) on delete cascade on update cascade,

  constraint fk_device foreign key (device)
  references fnbl_device (id) on delete cascade on update cascade  
);

create table fnbl_sync_source (
  uri        varchar(40)  binary not null,
  config     varchar(255) binary not null,
  name       varchar(200) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_sync_source primary key (uri)
);

create table fnbl_last_sync (
  principal          integer     not null,
  sync_source        varchar(40) binary not null,
  sync_type          integer     not null,
  status             integer,  
  last_anchor_server varchar(20) binary,
  last_anchor_client varchar(20) binary,
  start_sync         bigint,
  end_sync           bigint,
    
  constraint pk_last_sync primary key (principal, sync_source),
  
  constraint fk_principal foreign key (principal) 
  references fnbl_principal (id) on delete cascade on update cascade,

  constraint fk_source foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade on update cascade
);

create table fnbl_client_mapping (
  principal   integer      not null,
  sync_source varchar(40)  binary not null,
  luid        varchar(150) binary not null,
  guid        varchar(150) binary not null,
  last_anchor varchar(20)  binary,  
  
  constraint pk_clientmapping primary key (principal, sync_source, luid, guid),
  
  constraint fk_principal_cm foreign key (principal) 
  references fnbl_principal (id) on delete cascade on update cascade,

  constraint fk_source_cm foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade on update cascade
);

create table fnbl_id (
  idspace varchar(30) binary not null,
  counter integer     not null,
  
  constraint pk_id primary key (idspace)
);

create table fnbl_module (
  id          varchar(128) binary not null,
  name        varchar(200) binary not null,
  description varchar(200) binary,
  
  constraint pk_module primary key (id)
);

create table fnbl_sync_source_type (
  id          varchar(128) binary not null,
  description varchar(200) binary,
  class       varchar(255) binary not null,
  admin_class varchar(255) binary,
  
  constraint pk_sst primary key (id)
);

create table fnbl_module_sync_source_type (
  module     varchar(128) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_module_sst primary key (module, sourcetype)
);

create table fnbl_connector (
  id          varchar(128) binary not null,
  name        varchar(200) binary not null,
  description varchar(200) binary,
  admin_class varchar(255) binary,
    
  constraint pk_connector primary key (id)
);

create table fnbl_module_connector (
  module    varchar(128) binary not null,
  connector varchar(128) binary not null,
    
  constraint pk_mod_connector primary key (module, connector)
);

create table fnbl_connector_source_type (
  connector  varchar(128) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_connector_sst primary key (connector, sourcetype)
);

create table fnbl_role (
  role        varchar(128) binary not null,
  description varchar(200) binary not null,
 
  constraint pk_role primary key (role)
);

create table fnbl_user_role (
  username varchar(255)  binary not null,
  role     varchar(128)  binary not null,
 
  constraint pk_user_role primary key (username,role),
  
  constraint fk_userrole foreign key (username)
  references fnbl_user (username) on delete cascade on update cascade
);


create table fnbl_device_caps (
  id      integer     not null,
  version varchar(16) not null,
  man     varchar(100),
  model   varchar(100),
  fwv     varchar(100),
  swv     varchar(100),
  hwv     varchar(100),
  utc     char(1)     not null,
  lo      char(1)     not null,
  noc     char(1)     not null,
  
  constraint pk_device_caps primary key (id)
);


create table fnbl_device_ext (
  id     integer not null,
  caps   integer,
  xname  varchar(255),
  xvalue varchar(255),
  
  constraint pk_dev_ext primary key (id),
  
  constraint fk_dev_ext foreign key (caps)
  references fnbl_device_caps (id) on delete cascade on update cascade
);


create table fnbl_device_datastore (
  id          integer      not null,
  caps        integer     ,
  sourceref   varchar(128) not null,
  label       varchar(128),
  maxguidsize integer     ,
  dsmem       char(1)      not null,
  shs         char(1)      not null,
  synccap     varchar(32)  not null,
  
  constraint pk_dev_datastore primary key (id),
  
  constraint fk_dev_datastore foreign key (caps)
  references fnbl_device_caps (id) on delete cascade on update cascade
);

create table fnbl_ds_cttype_rx (
  datastore integer     not null,
  type      varchar(64) not null,
  version   varchar(16) not null,
  preferred char(1)     not null,
  
  constraint pk_ds_cttype_rx primary key (type,version,datastore),
  
  constraint fk_ds_cttype_rx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);

create table fnbl_ds_cttype_tx (
  datastore integer     not null,
  type      varchar(64) not null,
  version   varchar(16) not null,
  preferred char(1)     not null,
  
  constraint pk_ds_cttype_tx primary key (type,version,datastore),
  
  constraint fk_ds_cttype_tx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);

create table fnbl_ds_ctcap (
  id        integer     not null,
  datastore integer     not null,
  type      varchar(64) not null,
  version   varchar(16) not null,
  field     char(1)     not null,
  
  constraint pk_ds_ctcap primary key (id),
  
  constraint fk_ds_ctcap foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);

create table fnbl_ds_ctcap_prop (
  id        integer     not null,
  ctcap     integer     not null,
  name      varchar(64) not null,
  label     varchar(128),
  type      varchar(32) ,
  maxoccur  integer     ,
  maxsize   integer     ,
  truncated char(1)     not null,
  valenum   varchar(255),
  
  constraint pk_ds_ctcap_prop primary key (id),

  constraint fk_ds_ctcap_prop foreign key (ctcap) 
  references fnbl_ds_ctcap (id) on delete cascade on update cascade
);

create table fnbl_ds_ctcap_prop_param (
  property integer     not null,
  name     varchar(64) not null,
  label    varchar(128),
  type     varchar(32) ,
  valenum  varchar(255),
    
  constraint fk_ctcap_propparam foreign key (property) 
  references fnbl_ds_ctcap_prop (id) on delete cascade on update cascade
);

create table fnbl_ds_filter_rx (
  datastore integer     not null,
  type      varchar(64) not null,
  version   varchar(16) not null,
  
  constraint pk_ds_filter_rx primary key (type,version,datastore),

  constraint fk_ds_filter_rx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);

create table fnbl_ds_filter_cap (
  datastore  integer     not null,
  type       varchar(64) not null,
  version    varchar(16) not null,
  keywords   varchar(255),
  properties varchar(255),
  
  constraint pk_ds_filter_cap primary key (type,version,datastore),

  constraint fk_ds_filter_cap foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);

create table fnbl_ds_mem (
  datastore integer,
  shared    char(1) not null,
  maxmem    integer,
  maxid     integer,
   
  constraint fk_ds_mem foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade on update cascade
);


create index ind_user           on fnbl_user           (username, password);
create index ind_principal      on fnbl_principal      (username, device  );

create index ind_datastore      on fnbl_device_datastore    (caps     );
create index ind_cttype_rx      on fnbl_ds_cttype_rx        (datastore);
create index ind_cttype_tx      on fnbl_ds_cttype_tx        (datastore);
create index ind_ctcap          on fnbl_ds_ctcap            (datastore);
create index ind_ctcap_prop     on fnbl_ds_ctcap_prop       (ctcap    );
create index ind_ctcappropparam on fnbl_ds_ctcap_prop_param (property );
create index ind_filter_rx      on fnbl_ds_filter_rx        (datastore);
create index ind_filter_cap     on fnbl_ds_filter_cap       (datastore);
create index ind_mem            on fnbl_ds_mem              (datastore);
