--
-- This script contains the ddl to create the engine database.
--
-- @version $Id: create_engine.ddl,v 1.1 2006/08/08 08:27:49 nichele Exp $
--

create table fnbl_user (
  username   varchar2(255) not null,
  password   varchar2(255) not null,
  email      varchar2(50) ,
  first_name varchar2(255),
  last_name  varchar2(255),
  constraint pk_user primary key (username)
);

create table fnbl_device (
  id                   varchar2(128) not null,
  description          varchar2(255),
  type                 varchar2(255),
  client_nonce         varchar2(255),
  server_nonce         varchar2(255),
  server_password      varchar2(255),
  timezone             varchar2(32) ,
  convert_date         char(1)      ,
  charset              varchar2(16) ,
  address              varchar2(50) ,
  msisdn               varchar2(50) ,
  notification_builder varchar2(255),
  notification_sender  varchar2(255),
  id_caps              number       ,
  constraint pk_device primary key (id)
);

create table fnbl_principal (
  username varchar2(255) not null,
  device   varchar2(128) not null,
  id       number        not null,
  constraint pk_principal primary key (id),  
  constraint fk_user foreign key (username)
  references fnbl_user (username) on delete cascade,
  constraint fk_device foreign key (device)
  references fnbl_device (id) on delete cascade  
);

create table fnbl_sync_source (
  uri        varchar2(40)  not null,
  config     varchar2(255) not null,
  name       varchar2(200) not null,
  sourcetype varchar2(128) not null,
  constraint pk_sync_source primary key (uri)
);

create table fnbl_last_sync (
  principal          number        not null,
  sync_source        varchar2(128) not null,
  sync_type          number        not null,
  status             number      ,  
  last_anchor_server varchar2(20),
  last_anchor_client varchar2(20),
  start_sync         number(20)  ,
  end_sync           number(20)  ,
  constraint pk_last_sync primary key (principal, sync_source),  
  constraint fk_principal foreign key (principal) 
  references fnbl_principal (id) on delete cascade,
  constraint fk_source foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade
);

create table fnbl_client_mapping (
  principal   number        not null,
  sync_source varchar2(128) not null,
  luid        varchar2(200) not null,
  guid        varchar2(200) not null,
  last_anchor varchar2(20) ,
  constraint pk_clientmapping primary key (principal, sync_source, luid, guid),
  constraint fk_principal_cm foreign key (principal) 
  references fnbl_principal (id) on delete cascade,
  constraint fk_source_cm foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade
);

create table fnbl_id (
  idspace varchar2(30) not null,
  counter number       not null,
  constraint pk_id primary key (idspace)
);

create table fnbl_module (
  id          varchar2(128) not null,
  name        varchar(200)  not null,
  description varchar(200),
  constraint pk_module primary key (id)
);

create table fnbl_sync_source_type (
  id          varchar2(128) not null,
  description varchar2(200),
  class       varchar2(255) not null,
  admin_class varchar2(255),
  constraint pk_sst primary key (id)
);

create table fnbl_module_sync_source_type (
  module     varchar2(128) not null,
  sourcetype varchar2(128) not null,
  constraint pk_module_sst primary key (module, sourcetype)
);

create table fnbl_connector (
  id          varchar2(128) not null,
  name        varchar2(200) not null,
  description varchar2(200),
  admin_class varchar2(255),
  constraint pk_connector primary key (id)
);

create table fnbl_module_connector (
  module    varchar2(128) not null,
  connector varchar2(128) not null,
  constraint pk_mod_connector primary key (module, connector)
);

create table fnbl_connector_source_type (
  connector  varchar2(128) not null,
  sourcetype varchar2(128) not null,
  constraint pk_connector_sst primary key (connector, sourcetype)
);

create table fnbl_role (
  role        varchar2(128) not null,
  description varchar2(200) not null,
  constraint pk_role primary key (role)
);

create table fnbl_user_role (
  username varchar2(255) not null,
  role     varchar2(128) not null,
  constraint pk_user_role primary key (username,role),
  constraint fk_userrole foreign key (username)
  references fnbl_user (username) on delete cascade
);

create table fnbl_device_caps (
  id      number       not null,
  version varchar2(16) not null,
  man     varchar2(100),
  model   varchar2(100),
  fwv     varchar2(100),
  swv     varchar2(100),
  hwv     varchar2(100),
  utc     char(1)       not null,
  lo      char(1)       not null,
  noc     char(1)       not null,
  constraint pk_device_caps primary key (id)
);

create table fnbl_device_ext (
  id     number not null,
  caps   number,
  xname  varchar2(255),
  xvalue varchar2(255),
  constraint pk_dev_ext primary key (id),
  constraint fk_dev_ext foreign key (caps)
  references fnbl_device_caps (id) on delete cascade
);

create table fnbl_device_datastore (
  id          number        not null,
  caps        number       ,
  sourceref   varchar2(128) not null,
  label       varchar2(128),
  maxguidsize number       ,
  dsmem       char(1)       not null,
  shs         char(1)       not null,
  synccap     varchar2(32)  not null,
  constraint pk_dev_datastore primary key (id),
  constraint fk_dev_datastore foreign key (caps)
  references fnbl_device_caps (id) on delete cascade
);

create table fnbl_ds_cttype_rx (
  datastore number       not null,
  type      varchar2(64) not null,
  version   varchar2(16) not null,
  preferred char(1)      not null,
  constraint pk_ds_cttype_rx primary key (type,version,datastore),
  constraint fk_ds_cttype_rx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create table fnbl_ds_cttype_tx (
  datastore number       not null,
  type      varchar2(64) not null,
  version   varchar2(16) not null,
  preferred char(1)      not null,
  constraint pk_ds_cttype_tx primary key (type,version,datastore),
  constraint fk_ds_cttype_tx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create table fnbl_ds_ctcap (
  id        number       not null,
  datastore number       not null,
  type      varchar2(64) not null,
  version   varchar2(16) not null,
  field     char(1)      not null,
  constraint pk_ds_ctcap primary key (id),
  constraint fk_ds_ctcap foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create table fnbl_ds_ctcap_prop (
  id        number       not null,
  ctcap     number       not null,
  name      varchar2(64) not null,
  label     varchar2(128),
  type      varchar2(32) ,
  maxoccur  number       ,
  maxsize   number       ,
  truncated char(1)       not null,
  valenum   varchar2(255),
  constraint pk_ds_ctcap_prop primary key (id),
  constraint fk_ds_ctcap_prop foreign key (ctcap) 
  references fnbl_ds_ctcap (id) on delete cascade
);

create table fnbl_ds_ctcap_prop_param (
  property number        not null,
  name     varchar2(64)  not null,
  label    varchar2(128),
  type     varchar2(32) ,
  valenum  varchar2(255),
  constraint fk_ctcap_propparam foreign key (property) 
  references fnbl_ds_ctcap_prop (id) on delete cascade
);

create table fnbl_ds_filter_rx (
  datastore number       not null,
  type      varchar2(64) not null,
  version   varchar2(16) not null,
  constraint pk_ds_filter_rx primary key (type,version,datastore),
  constraint fk_ds_filter_rx foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create table fnbl_ds_filter_cap (
  datastore  number        not null,
  type       varchar2(64)  not null,
  version    varchar2(16)  not null,
  keywords   varchar2(255),
  properties varchar2(255),
  constraint pk_ds_filter_cap primary key (type,version,datastore),
  constraint fk_ds_filter_cap foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create table fnbl_ds_mem (
  datastore number,
  shared    char(1) not null,
  maxmem    number,
  maxid     number,
  constraint fk_ds_mem foreign key (datastore) 
  references fnbl_device_datastore (id) on delete cascade
);

create index ind_user           on fnbl_user           (username, password);
create index ind_principal      on fnbl_principal      (username, device  );

create index ind_datastore      on fnbl_device_datastore    (caps     );
create index ind_cttype_rx      on fnbl_ds_cttype_rx        (datastore);
create index ind_cttype_tx      on fnbl_ds_cttype_tx        (datastore);
create index ind_ctcap          on fnbl_ds_ctcap            (datastore);
create index ind_ctcap_prop     on fnbl_ds_ctcap_prop       (ctcap    );
create index ind_ctcappropparam on fnbl_ds_ctcap_prop_param (property );
create index ind_filter_rx      on fnbl_ds_filter_rx        (datastore);
create index ind_filter_cap     on fnbl_ds_filter_cap       (datastore);
create index ind_mem            on fnbl_ds_mem              (datastore);
